Method: Bitmex::User#min_withdrawal_fee
- Defined in:
- lib/bitmex/user.rb
#min_withdrawal_fee(currency = 'XBt') ⇒ Hash
Get the minimum withdrawal fee for a currency This is changed based on network conditions to ensure timely withdrawals. During network congestion, this may be high. The fee is returned in the same currency.
71 72 73 |
# File 'lib/bitmex/user.rb', line 71 def min_withdrawal_fee(currency = 'XBt') get 'minWithdrawalFee', currency: currency end |